@@ -16,14 +16,15 @@ from nibabel import Nifti1Image, spatialimages
 from numpy.testing import assert_array_equal
 
 import nilearn as ni
-from nilearn._utils import (
+from nilearn._utils.exceptions import DimensionError
+from nilearn._utils.niimg import repr_niimgs
+from nilearn._utils.niimg_conversions import (
     check_niimg,
     check_niimg_3d,
     check_niimg_4d,
-    repr_niimgs,
+    check_same_fov,
+    iter_check_niimg,
 )
-from nilearn._utils.exceptions import DimensionError
-from nilearn._utils.niimg_conversions import check_same_fov, iter_check_niimg
 from nilearn._utils.testing import (
     assert_memory_less_than,
     with_memory_profiler,
