@@ -45,9 +45,13 @@ if is_matplotlib_installed():
     if compare_version(
         matplotlib.__version__, ">", OPTIONAL_MATPLOTLIB_MIN_VERSION
     ):
+        # the tests that compare plotted figures
+        # against their expected baseline is only run
+        # with the oldest version of matplolib
         collect_ignore.extend(
             [
                 "plotting/tests/test_baseline_comparisons.py",
+                "reporting/tests/test_baseline_comparisons.py",
             ]
         )
 
@@ -58,6 +62,7 @@ else:
             "plotting",
             "reporting/html_report.py",
             "reporting/tests/test_html_report.py",
+            "reporting/tests/test_baseline_comparisons.py",
         ]
     )
     matplotlib = None  # type: ignore[assignment]
@@ -126,6 +131,7 @@ def close_all():
 def suppress_specific_warning():
     """Ignore internal deprecation warnings."""
     with warnings.catch_warnings():
+        # TODO (nilearn >= 0.13.0) deprecate nearest interpolation
         messages = (
             "The `darkness` parameter will be deprecated.*|"
             "In release 0.13, this fetcher will return a dictionary.*|"
