@@ -9,14 +9,16 @@ import warnings
 
 import numpy as np
 import scipy.linalg
-from joblib import Memory, Parallel, delayed
+from joblib import Parallel, delayed
 from sklearn.base import BaseEstimator
 from sklearn.covariance import empirical_covariance
 from sklearn.model_selection import check_cv
 from sklearn.utils import check_array
 from sklearn.utils.extmath import fast_logdet
 
-from nilearn._utils import CacheMixin, fill_doc, logger
+from nilearn._utils import logger
+from nilearn._utils.cache_mixin import CacheMixin
+from nilearn._utils.docs import fill_doc
 from nilearn._utils.extmath import is_spd
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.param_validation import check_params
@@ -167,8 +169,7 @@ def group_sparse_covariance(
         number of samples, sensible values lie in the [0, 1] range(zero is
         no regularization: output is not sparse)
 
-    max_iter : :obj:`int`, default=50
-        maximum number of iterations.
+    %(max_iter50)s
 
     tol : positive :obj:`float` or None, default=0.001
         The tolerance to declare convergence: if the duality gap goes below
@@ -561,9 +562,8 @@ class GroupSparseCovariance(CacheMixin, BaseEstimator):
         The tolerance to declare convergence: if the dual gap goes below
         this value, iterations are stopped.
 
-    max_iter : :obj:`int`, default=10
-        maximum number of iterations. The default value is rather
-        conservative.
+    %(max_iter10)s
+        The default value is rather conservative.
 
     %(verbose0)s
 
@@ -576,6 +576,11 @@ class GroupSparseCovariance(CacheMixin, BaseEstimator):
     covariances_ : numpy.ndarray, shape (n_features, n_features, n_subjects)
         empirical covariance matrices.
 
+    memory_ : joblib memory cache
+
+    n_features_in_ : :obj:`int`
+        Number of features seen during fit.
+
     precisions_ : numpy.ndarraye, shape (n_features, n_features, n_subjects)
         precisions matrices estimated using the group-sparse algorithm.
 
@@ -605,7 +610,7 @@ class GroupSparseCovariance(CacheMixin, BaseEstimator):
     def _more_tags(self):
         """Return estimator tags.
 
-        TODO remove when bumping sklearn_version > 1.5
+        TODO (sklearn >= 1.6.0) remove
         """
         return self.__sklearn_tags__()
 
@@ -649,17 +654,36 @@ class GroupSparseCovariance(CacheMixin, BaseEstimator):
         """
         del y
         check_params(self.__dict__)
-        for x in subjects:
-            check_array(x, accept_sparse=False)
 
-        if self.memory is None:
-            self.memory = Memory(location=None)
+        # casting single arrays to list mostly to help
+        # with checking comlpliance with sklearn estimator guidelines
+        if isinstance(subjects, np.ndarray):
+            subjects = [subjects]
+
+        if not isinstance(subjects, list):
+            raise TypeError(
+                "'subjects' must be a list of arrays. "
+                f"Got {subjects.__class__.__name__}"
+            )
+
+        for x in subjects:
+            check_array(
+                x,
+                accept_sparse=False,
+                ensure_2d=True,
+                ensure_min_features=2,
+                ensure_min_samples=2,
+            )
+
+        self._fit_cache()
 
         logger.log("Computing covariance matrices", verbose=self.verbose)
         self.covariances_, n_samples = empirical_covariances(
             subjects, assume_centered=False
         )
 
+        self.n_features_in_ = next(iter(s.shape[1] for s in subjects))
+
         logger.log("Computing precision matrices", verbose=self.verbose)
         ret = self._cache(_group_sparse_covariance)(
             self.covariances_,
@@ -993,7 +1017,7 @@ class EarlyStopProbe:
 
 
 @fill_doc
-class GroupSparseCovarianceCV(CacheMixin, BaseEstimator):
+class GroupSparseCovarianceCV(BaseEstimator):
     """Sparse inverse covariance w/ cross-validated choice of the parameter.
 
     A cross-validated value for the regularization parameter is first
@@ -1027,8 +1051,7 @@ class GroupSparseCovarianceCV(CacheMixin, BaseEstimator):
         tolerance used during the final optimization for determining precision
         matrices value.
 
-    max_iter : :obj:`int`, default=100
-        maximum number of iterations in the final optimization.
+    %(max_iter100)s
 
     %(verbose0)s
 
@@ -1108,7 +1131,7 @@ class GroupSparseCovarianceCV(CacheMixin, BaseEstimator):
     def _more_tags(self):
         """Return estimator tags.
 
-        TODO remove when bumping sklearn_version > 1.5
+        TODO (sklearn >= 1.6.0) remove
         """
         return self.__sklearn_tags__()
 
@@ -1152,8 +1175,25 @@ class GroupSparseCovarianceCV(CacheMixin, BaseEstimator):
         del y
         check_params(self.__dict__)
 
+        # casting single arrays to list mostly to help
+        # with checking comlpliance with sklearn estimator guidelines
+        if isinstance(subjects, np.ndarray):
+            subjects = [subjects]
+
+        if not isinstance(subjects, list):
+            raise TypeError(
+                "'subjects' must be a list of 2D numpy arrays. "
+                f"Got {subjects.__class__.__name__}"
+            )
+
         for x in subjects:
-            check_array(x, accept_sparse=False)
+            check_array(
+                x,
+                accept_sparse=False,
+                ensure_2d=True,
+                ensure_min_features=2,
+                ensure_min_samples=2,
+            )
 
         # Empirical covariances
         emp_covs, n_samples = empirical_covariances(
@@ -1161,6 +1201,8 @@ class GroupSparseCovarianceCV(CacheMixin, BaseEstimator):
         )
         n_subjects = emp_covs.shape[2]
 
+        self.n_features_in_ = next(iter(s.shape[1] for s in subjects))
+
         # One cv generator per subject must be created, because each subject
         # can have a different number of samples from the others.
         cv = [
