@@ -4,6 +4,7 @@ from math import sqrt
 
 import numpy as np
 
+from nilearn._utils.docs import fill_doc
 from nilearn.masking import unmask_from_to_3d_array
 
 from ._objective_functions import (
@@ -467,6 +468,7 @@ def _tvl1_objective(X, y, w, alpha, l1_ratio, mask, loss="mse"):
     return out
 
 
+@fill_doc
 def tvl1_solver(
     X,
     y,
@@ -509,8 +511,7 @@ def tvl1_solver(
         The support of this mask defines the ROIs being considered in
         the problem.
 
-    max_iter : :obj:`int`, default=100
-        Defines the iterations for the solver.
+    %(max_iter100)s
 
     prox_max_iter : :obj:`int`, default=5000
         Maximum number of iterations for inner FISTA loop in which
