@@ -12,7 +12,8 @@ from pathlib import Path
 from string import Template
 
 import numpy as np
-from joblib import Memory, Parallel, delayed
+from joblib import Parallel, delayed
+from nibabel import Nifti1Image
 from scipy import linalg
 from sklearn.base import BaseEstimator, TransformerMixin
 from sklearn.linear_model import LinearRegression
@@ -21,11 +22,13 @@ from sklearn.utils.estimator_checks import check_is_fitted
 from sklearn.utils.extmath import randomized_svd, svd_flip
 
 import nilearn
-from nilearn._utils import fill_doc, logger
-from nilearn._utils.cache_mixin import CacheMixin, cache
+from nilearn._utils import logger
+from nilearn._utils.cache_mixin import CacheMixin
+from nilearn._utils.docs import fill_doc
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.masker_validation import check_embedded_masker
 from nilearn._utils.niimg import safe_get_data
+from nilearn._utils.niimg_conversions import check_niimg
 from nilearn._utils.param_validation import check_params
 from nilearn._utils.path_finding import resolve_globbing
 from nilearn._utils.tags import SKLEARN_LT_1_6
@@ -140,8 +143,6 @@ def _mask_and_reduce(
     reduction_ratio="auto",
     n_components=None,
     random_state=None,
-    memory_level=0,
-    memory=None,
     n_jobs=1,
 ):
     """Mask and reduce provided 4D images with given masker.
@@ -179,14 +180,6 @@ def _mask_and_reduce(
     %(random_state)s
         default=0
 
-    memory_level : integer, default=0
-        Integer indicating the level of memorization. The higher, the more
-        function calls are cached.
-
-    memory : joblib.Memory, default=None
-        Used to cache the function calls.
-        If ``None`` is passed will default to ``Memory(location=None)``.
-
     n_jobs : integer, default=1
         The number of CPUs to use to do the computation. -1 means
         'all CPUs', -2 'all CPUs but one', and so on.
@@ -197,8 +190,6 @@ def _mask_and_reduce(
         Concatenation of reduced data.
 
     """
-    if memory is None:
-        memory = Memory(location=None)
     if not hasattr(imgs, "__iter__"):
         imgs = [imgs]
 
@@ -235,8 +226,6 @@ def _mask_and_reduce(
             confound,
             reduction_ratio=reduction_ratio,
             n_samples=n_samples,
-            memory=memory,
-            memory_level=memory_level,
             random_state=random_state,
         )
         for img, confound in zip(imgs, confounds)
@@ -270,8 +259,6 @@ def _mask_and_reduce_single(
     confound,
     reduction_ratio=None,
     n_samples=None,
-    memory=None,
-    memory_level=0,
     random_state=None,
 ):
     """Implement multiprocessing from MaskReducer."""
@@ -292,9 +279,9 @@ def _mask_and_reduce_single(
     else:
         n_samples = ceil(data_n_samples * reduction_ratio)
 
-    U, S, V = cache(
-        _fast_svd, memory, memory_level=memory_level, func_memory_level=3
-    )(this_data.T, n_samples, random_state=random_state)
+    U, S, V = masker._cache(_fast_svd, func_memory_level=3)(
+        this_data.T, n_samples, random_state=random_state
+    )
     U = U.T.copy()
     U = U * S[:, np.newaxis]
     return U
@@ -394,7 +381,7 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
 
     %(verbose0)s
 
-    %(base_decomposition_attributes)s
+    %(base_decomposition_fit_attributes)s
     """
 
     def __init__(
@@ -441,7 +428,7 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
     def _more_tags(self):
         """Return estimator tags.
 
-        TODO remove when bumping sklearn_version > 1.5
+        TODO (sklearn >= 1.6.0) remove
         """
         return self.__sklearn_tags__()
 
@@ -451,8 +438,7 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
         See the sklearn documentation for more details on tags
         https://scikit-learn.org/1.6/developers/develop.html#estimator-tags
         """
-        # TODO
-        # get rid of if block
+        # TODO (sklearn  >= 1.6.0) remove if block
         if SKLEARN_LT_1_6:
             from nilearn._utils.tags import tags
 
@@ -520,6 +506,14 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
                 "an empty list was given."
             )
 
+        if confounds is not None and len(confounds) != len(imgs):
+            raise ValueError(
+                f"Number of confounds ({len(confounds)=}) "
+                f"must match number of images ({len(imgs)=})."
+            )
+
+        self._fit_cache()
+
         masker_type = "multi_nii"
         if isinstance(self.mask, (SurfaceMasker, SurfaceImage)) or any(
             isinstance(x, SurfaceImage) for x in imgs
@@ -527,6 +521,7 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
             masker_type = "surface"
             _warn_ignored_surface_masker_params(self)
         self.masker_ = check_embedded_masker(self, masker_type=masker_type)
+        self.masker_.memory_level = self.memory_level
 
         # Avoid warning with imgs != None
         # if masker_ has been provided a mask_img
@@ -545,8 +540,6 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
             confounds=confounds,
             n_components=self.n_components,
             random_state=self.random_state,
-            memory=self.memory,
-            memory_level=max(0, self.memory_level + 1),
             n_jobs=self.n_jobs,
         )
         self._raw_fit(data)
@@ -565,11 +558,13 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
             )
         self.maps_masker_.fit()
 
+        self.n_elements_ = self.maps_masker_.n_elements_
+
         return self
 
     @property
     def nifti_maps_masker_(self):
-        # TODO: remove in 0.13
+        # TODO (nilearn >= 0.13.0) remove
         warnings.warn(
             message="The 'nifti_maps_masker_' attribute is deprecated "
             "and will be removed in Nilearn 0.13.0.\n"
@@ -608,8 +603,20 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
         check_is_fitted(self)
 
         # XXX: dealing properly with 4D/ list of 4D data?
+        if isinstance(imgs, (str, Path)):
+            imgs = check_niimg(imgs)
+
+        if isinstance(imgs, (SurfaceImage, Nifti1Image)):
+            imgs = [imgs]
+
         if confounds is None:
-            confounds = [None] * len(imgs)
+            confounds = list(itertools.repeat(None, len(imgs)))
+        elif len(confounds) != len(imgs):
+            raise ValueError(
+                f"Number of confounds ({len(confounds)=}) "
+                f"must match number of images ({len(imgs)=})."
+            )
+
         return [
             self.maps_masker_.transform(img, confounds=confound)
             for img, confound in zip(imgs, confounds)
@@ -635,6 +642,12 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
         check_is_fitted(self)
 
         # XXX: dealing properly with 2D/ list of 2D data?
+        if not isinstance(loadings, list):
+            raise TypeError(
+                "'loadings' must be a list of numpy arrays. "
+                f"Got: {loadings.__class__.__name__}"
+            )
+
         return [
             self.maps_masker_.inverse_transform(loading)
             for loading in loadings
@@ -654,7 +667,7 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
             data, self.components_, per_component=per_component
         )
 
-    def score(self, imgs, confounds=None, per_component=False):
+    def score(self, imgs, y=None, confounds=None, per_component=False):
         """Score function based on explained variance on imgs.
 
         Should only be used by DecompositionEstimator derived classes
@@ -666,6 +679,8 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
             See :ref:`extracting_data`.
             Data to be scored
 
+        %(y_dummy)s
+
         confounds : CSV file path or numpy.ndarray
             or pandas DataFrame, optional
             This parameter is passed to nilearn.signal.clean. Please see the
@@ -683,6 +698,7 @@ class _BaseDecomposition(CacheMixin, TransformerMixin, BaseEstimator):
             is squeezed if the number of subjects is one
 
         """
+        del y
         check_is_fitted(self)
 
         data = _mask_and_reduce(
