@@ -12,7 +12,8 @@ from scipy.interpolate import interp1d
 from scipy.linalg import pinv
 from scipy.stats import gamma
 
-from nilearn._utils import fill_doc, rename_parameters
+from nilearn._utils.docs import fill_doc
+from nilearn._utils.helpers import rename_parameters
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.param_validation import check_params
 
@@ -85,6 +86,7 @@ def _gamma_difference_hrf(
     return hrf
 
 
+# TODO (nilearn >= 0.13.0)
 @rename_parameters({"tr": "t_r"}, end_version="0.13.0")
 def spm_hrf(t_r, oversampling=50, time_length=32.0, onset=0.0):
     """Implement the :term:`SPM` :term:`HRF` model.
@@ -118,6 +120,7 @@ def spm_hrf(t_r, oversampling=50, time_length=32.0, onset=0.0):
     return _gamma_difference_hrf(t_r, oversampling, time_length, onset)
 
 
+# TODO (nilearn >= 0.13.0)
 @rename_parameters({"tr": "t_r"}, end_version="0.13.0")
 def glover_hrf(t_r, oversampling=50, time_length=32.0, onset=0.0):
     """Implement the Glover :term:`HRF` model.
@@ -198,6 +201,7 @@ def _generic_time_derivative(
     )
 
 
+# TODO (nilearn >= 0.13.0)
 @rename_parameters({"tr": "t_r"}, end_version="0.13.0")
 def spm_time_derivative(t_r, oversampling=50, time_length=32.0, onset=0.0):
     """Implement the :term:`SPM` time derivative :term:`HRF` (dhrf) model.
@@ -237,6 +241,7 @@ def spm_time_derivative(t_r, oversampling=50, time_length=32.0, onset=0.0):
     )
 
 
+# TODO (nilearn >= 0.13.0)
 @rename_parameters({"tr": "t_r"}, end_version="0.13.0")
 def glover_time_derivative(t_r, oversampling=50, time_length=32.0, onset=0.0):
     """Implement the Glover time derivative :term:`HRF` (dhrf) model.
@@ -318,6 +323,7 @@ def _generic_dispersion_derivative(
     )
 
 
+# TODO (nilearn >= 0.13.0)
 @rename_parameters({"tr": "t_r"}, end_version="0.13.0")
 def spm_dispersion_derivative(
     t_r, oversampling=50, time_length=32.0, onset=0.0
@@ -355,6 +361,7 @@ def spm_dispersion_derivative(
     )
 
 
+# TODO (nilearn >= 0.13.0)
 @rename_parameters({"tr": "t_r"}, end_version="0.13.0")
 def glover_dispersion_derivative(
     t_r, oversampling=50, time_length=32.0, onset=0.0
