@@ -10,11 +10,12 @@ import numpy as np
 from scipy import linalg
 from scipy.ndimage import affine_transform, find_objects
 
-from nilearn import _utils
-from nilearn._utils import fill_doc, stringify_path
-from nilearn._utils.helpers import check_copy_header
+from nilearn._utils.docs import fill_doc
+from nilearn._utils.helpers import check_copy_header, stringify_path
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.niimg import _get_data
+from nilearn._utils.niimg_conversions import check_niimg, check_niimg_3d
+from nilearn._utils.numpy_conversions import as_ndarray
 from nilearn.image.image import copy_img, crop_img
 
 ###############################################################################
@@ -220,10 +221,8 @@ def get_mask_bounds(img):
     reorder_img to ensure that it is the case.
 
     """
-    img = _utils.check_niimg_3d(img)
-    mask = _utils.numpy_conversions.as_ndarray(
-        _get_data(img), dtype=bool, copy=False
-    )
+    img = check_niimg_3d(img)
+    mask = as_ndarray(_get_data(img), dtype=bool, copy=False)
     affine = img.affine
     (xmin, xmax), (ymin, ymax), (zmin, zmax) = get_bounds(mask.shape, affine)
     slices = find_objects(mask.astype(int))
@@ -255,8 +254,6 @@ class BoundingBoxError(ValueError):
     matrix does not contain any of the original data.
     """
 
-    pass
-
 
 ###############################################################################
 # Resampling
@@ -337,6 +334,7 @@ def _resample_one_img(
 
 
 def _check_force_resample(force_resample):
+    # TODO (nilearn 0.13.0)
     if force_resample is None:
         force_resample = False
         warnings.warn(
@@ -468,13 +466,13 @@ def resample_img(
     from .image import new_img_like  # avoid circular imports
 
     force_resample = _check_force_resample(force_resample)
-    # TODO: remove this warning in 0.13.0
+    # TODO (nilearn >= 0.13.0) remove this warning
     check_copy_header(copy_header)
 
     _check_resample_img_inputs(target_shape, target_affine, interpolation)
 
     img = stringify_path(img)
-    img = _utils.check_niimg(img)
+    img = check_niimg(img)
 
     # If later on we want to impute sform using qform add this condition
     # see : https://github.com/nilearn/nilearn/issues/3168#issuecomment-1159447771  # noqa: E501
@@ -814,7 +812,7 @@ def resample_to_img(
     """
     force_resample = _check_force_resample(force_resample)
 
-    target = _utils.check_niimg(target_img)
+    target = check_niimg(target_img)
     target_shape = target.shape
 
     # When target shape is greater than 3, we reduce to 3, to be compatible
@@ -867,7 +865,7 @@ def reorder_img(img, resample=None, copy_header=False):
     from .image import new_img_like
 
     check_copy_header(copy_header)
-    img = _utils.check_niimg(img)
+    img = check_niimg(img)
     # The copy is needed in order not to modify the input img affine
     # see https://github.com/nilearn/nilearn/issues/325 for a concrete bug
     affine = img.affine.copy()
@@ -882,8 +880,7 @@ def reorder_img(img, resample=None, copy_header=False):
         # Identify the voxel size using a QR decomposition of the affine
         Q, R = np.linalg.qr(affine[:3, :3])
         target_affine = np.diag(np.abs(np.diag(R))[np.abs(Q).argmax(axis=1)])
-        # TODO switch to force_resample=True
-        # when bumping to version > 0.13
+        # TODO (nilearn >= 0.13.0) force_resample=True
         return resample_img(
             img,
             target_affine=target_affine,
