@@ -16,13 +16,17 @@ from sklearn.utils.estimator_checks import check_is_fitted
 from sklearn.utils.validation import check_array
 
 from nilearn._utils import logger
+from nilearn._utils.bids import (
+    generate_atlas_look_up_table,
+    sanitize_look_up_table,
+)
 from nilearn._utils.cache_mixin import CacheMixin, cache
 from nilearn._utils.docs import fill_doc
 from nilearn._utils.helpers import (
     rename_parameters,
     stringify_path,
 )
-from nilearn._utils.logger import find_stack_level, log
+from nilearn._utils.logger import find_stack_level
 from nilearn._utils.masker_validation import (
     check_compatibility_mask_and_images,
 )
@@ -37,6 +41,7 @@ from nilearn.image import (
     resample_img,
     smooth_img,
 )
+from nilearn.image.image import get_indices_from_image
 from nilearn.masking import load_mask_img, unmask
 from nilearn.signal import clean
 from nilearn.surface.surface import SurfaceImage, at_least_2d, check_surf_img
@@ -87,10 +92,7 @@ def filter_and_extract(
     if isinstance(imgs, str):
         copy = False
 
-    log(
-        f"Loading data from {repr_niimgs(imgs, shorten=False)}",
-        verbose=verbose,
-    )
+    mask_logger("load_data", imgs, verbose)
 
     # Convert input to niimg to check shape.
     # This must be repeated after the shape check because check_niimg will
@@ -102,7 +104,7 @@ def filter_and_extract(
     target_shape = parameters.get("target_shape")
     target_affine = parameters.get("target_affine")
     if target_shape is not None or target_affine is not None:
-        log("Resampling images")
+        logger.log("Resampling images")
 
         imgs = cache(
             resample_img,
@@ -122,7 +124,7 @@ def filter_and_extract(
 
     smoothing_fwhm = parameters.get("smoothing_fwhm")
     if smoothing_fwhm is not None:
-        log("Smoothing images", verbose=verbose)
+        logger.log("Smoothing images", verbose=verbose)
 
         imgs = cache(
             smooth_img,
@@ -131,7 +133,7 @@ def filter_and_extract(
             memory_level=memory_level,
         )(imgs, parameters["smoothing_fwhm"])
 
-    log("Extracting region signals", verbose=verbose)
+    mask_logger("extracting", verbose=verbose)
 
     region_signals, aux = cache(
         extraction_function,
@@ -147,7 +149,7 @@ def filter_and_extract(
     # Confounds removing (from csv file or numpy array)
     # Normalizing
 
-    log("Cleaning extracted signals", verbose=verbose)
+    mask_logger("cleaning", verbose=verbose)
 
     runs = parameters.get("runs", None)
     region_signals = cache(
@@ -211,6 +213,38 @@ def prepare_confounds_multimaskers(masker, imgs_list, confounds):
     return confounds
 
 
+def mask_logger(step, img=None, verbose=0):
+    """Log similar messages for all maskers."""
+    repr = None
+    if img is not None:
+        repr = img.__repr__()
+        if verbose > 1:
+            repr = repr_niimgs(img, shorten=True)
+        elif verbose > 2:
+            repr = repr_niimgs(img, shorten=False)
+
+    messages = {
+        "cleaning": "Cleaning extracted signals",
+        "compute_mask": "Computing mask",
+        "extracting": "Extracting region signals",
+        "fit_done": "Finished fit",
+        "inverse_transform": "Computing image from signals",
+        "load_data": f"Loading data from {repr}",
+        "load_mask": f"Loading mask from {repr}",
+        "load_regions": f"Loading regions from {repr}",
+        "resample_mask": "Resamping mask",
+        "resample_regions": "Resampling regions",
+    }
+
+    if step not in messages:
+        raise ValueError(f"Unknown step: {step}")
+
+    if step in ["load_mask", "load_data"] and repr is None:
+        return
+
+    logger.log(messages[step], verbose=verbose)
+
+
 @fill_doc
 class BaseMasker(TransformerMixin, CacheMixin, BaseEstimator):
     """Base class for NiftiMaskers."""
@@ -232,7 +266,7 @@ class BaseMasker(TransformerMixin, CacheMixin, BaseEstimator):
 
         %(sample_mask)s
 
-                .. versionadded:: 0.8.0
+            .. versionadded:: 0.8.0
 
         copy : :obj:`bool`, default=True
             Indicates whether a copy is returned or not.
@@ -247,7 +281,7 @@ class BaseMasker(TransformerMixin, CacheMixin, BaseEstimator):
     def _more_tags(self):
         """Return estimator tags.
 
-        TODO remove when bumping sklearn_version > 1.5
+        TODO (sklearn >= 1.6.0) remove
         """
         return self.__sklearn_tags__()
 
@@ -257,9 +291,7 @@ class BaseMasker(TransformerMixin, CacheMixin, BaseEstimator):
         See the sklearn documentation for more details on tags
         https://scikit-learn.org/1.6/developers/develop.html#estimator-tags
         """
-        # TODO
-        # get rid of if block
-        # bumping sklearn_version > 1.5
+        # TODO (sklearn  >= 1.6.0) remove if block
         if SKLEARN_LT_1_6:
             from nilearn._utils.tags import tags
 
@@ -273,7 +305,6 @@ class BaseMasker(TransformerMixin, CacheMixin, BaseEstimator):
 
     def fit(self, imgs=None, y=None):
         """Present only to comply with sklearn estimators checks."""
-        ...
 
     def _load_mask(self, imgs):
         """Load and validate mask if one passed at init.
@@ -288,9 +319,7 @@ class BaseMasker(TransformerMixin, CacheMixin, BaseEstimator):
             # other nifti maskers are OK with None
             return None
 
-        repr = repr_niimgs(self.mask_img, shorten=(not self.verbose))
-        msg = f"loading mask from {repr}"
-        log(msg=msg, verbose=self.verbose)
+        mask_logger("load_mask", img=self.mask_img, verbose=self.verbose)
 
         # ensure that the mask_img_ is a 3D binary image
         tmp = check_niimg(self.mask_img, atleast_4d=True)
@@ -320,7 +349,7 @@ class BaseMasker(TransformerMixin, CacheMixin, BaseEstimator):
 
         %(sample_mask)s
 
-                .. versionadded:: 0.8.0
+            .. versionadded:: 0.8.0
 
         Returns
         -------
@@ -348,6 +377,7 @@ class BaseMasker(TransformerMixin, CacheMixin, BaseEstimator):
             imgs, confounds=all_confounds, sample_mask=sample_mask
         )
 
+    # TODO (nilearn >= 0.13.0)
     @fill_doc
     @rename_parameters(replacement_params={"X": "imgs"}, end_version="0.13.0")
     def fit_transform(
@@ -367,7 +397,7 @@ class BaseMasker(TransformerMixin, CacheMixin, BaseEstimator):
 
         %(sample_mask)s
 
-                .. versionadded:: 0.8.0
+            .. versionadded:: 0.8.0
 
         Returns
         -------
@@ -428,6 +458,8 @@ class BaseMasker(TransformerMixin, CacheMixin, BaseEstimator):
         # with some GLM inputs
         X = self._check_array(X, sklearn_check=False)
 
+        mask_logger("inverse_transform", verbose=self.verbose)
+
         img = self._cache(unmask)(X, self.mask_img_)
         # Be robust again memmapping that will create read-only arrays in
         # internal structures of the header: remove the memmaped array
@@ -481,11 +513,12 @@ class BaseMasker(TransformerMixin, CacheMixin, BaseEstimator):
     def _sanitize_cleaning_parameters(self):
         """Make sure that cleaning parameters are passed via clean_args.
 
-        TODO remove when bumping to nilearn >0.13
+        TODO (nilearn >= 0.13.0) remove
         """
         if hasattr(self, "clean_kwargs"):
             if self.clean_kwargs:
                 tmp = [", ".join(list(self.clean_kwargs))]
+                # TODO (nilearn >= 0.13.0)
                 warnings.warn(
                     f"You passed some kwargs to {self.__class__.__name__}: "
                     f"{tmp}. "
@@ -512,7 +545,7 @@ class _BaseSurfaceMasker(TransformerMixin, CacheMixin, BaseEstimator):
     def _more_tags(self):
         """Return estimator tags.
 
-        TODO remove when bumping sklearn_version > 1.5
+        TODO (sklearn >= 1.6.0) remove
         """
         return self.__sklearn_tags__()
 
@@ -522,8 +555,7 @@ class _BaseSurfaceMasker(TransformerMixin, CacheMixin, BaseEstimator):
         See the sklearn documentation for more details on tags
         https://scikit-learn.org/1.6/developers/develop.html#estimator-tags
         """
-        # TODO
-        # get rid of if block
+        # TODO (sklearn  >= 1.6.0) remove if block
         if SKLEARN_LT_1_6:
             from nilearn._utils.tags import tags
 
@@ -563,10 +595,7 @@ class _BaseSurfaceMasker(TransformerMixin, CacheMixin, BaseEstimator):
 
         mask_img_ = deepcopy(self.mask_img)
 
-        logger.log(
-            msg=f"loading mask from {mask_img_.__repr__()}",
-            verbose=self.verbose,
-        )
+        mask_logger("load_mask", img=mask_img_, verbose=self.verbose)
 
         mask_img_ = at_least_2d(mask_img_)
         mask = {}
@@ -596,6 +625,7 @@ class _BaseSurfaceMasker(TransformerMixin, CacheMixin, BaseEstimator):
 
         return mask_img_
 
+    # TODO (nilearn >= 0.13.0)
     @rename_parameters(
         replacement_params={"img": "imgs"}, end_version="0.13.0"
     )
@@ -672,6 +702,7 @@ class _BaseSurfaceMasker(TransformerMixin, CacheMixin, BaseEstimator):
         # implemented in children classes
         raise NotImplementedError()
 
+    # TODO (nilearn >= 0.13.0)
     @rename_parameters(
         replacement_params={"img": "imgs"}, end_version="0.13.0"
     )
@@ -737,3 +768,81 @@ class _BaseSurfaceMasker(TransformerMixin, CacheMixin, BaseEstimator):
             This has not been implemented yet.
         """
         raise NotImplementedError()
+
+
+def generate_lut(labels_img, background_label, lut=None, labels=None):
+    """Generate a look up table if one was not provided.
+
+    Also sanitize its content if necessary.
+
+    Parameters
+    ----------
+    labels_img : Nifti1Image | SurfaceImage
+
+    background_label : int | float
+
+    lut : Optional[str, Path, pd.DataFrame]
+
+    labels : Optional[list[str]]
+    """
+    labels_present = get_indices_from_image(labels_img)
+    add_background_to_lut = (
+        None if background_label not in labels_present else background_label
+    )
+
+    if lut is not None:
+        if isinstance(lut, (str, Path)):
+            lut = pd.read_table(lut, sep=None, engine="python")
+
+    elif labels:
+        lut = generate_atlas_look_up_table(
+            function=None,
+            name=deepcopy(labels),
+            index=labels_img,
+            background_label=add_background_to_lut,
+        )
+
+    else:
+        lut = generate_atlas_look_up_table(
+            function=None,
+            index=labels_img,
+            background_label=add_background_to_lut,
+        )
+
+    assert isinstance(lut, pd.DataFrame)
+
+    # passed labels or lut may not include background label
+    # because of poor data standardization
+    # so we need to update the lut accordingly
+    mask_background_index = lut["index"] == background_label
+    if (mask_background_index).any():
+        # Ensure background is the first row with name "Background"
+        # Shift the 'name' column down by one
+        # if background row was not named properly
+        first_rows = lut[mask_background_index]
+        other_rows = lut[~mask_background_index]
+        lut = pd.concat([first_rows, other_rows], ignore_index=True)
+
+        mask_background_name = lut["name"] == "Background"
+        if not (mask_background_name).any():
+            lut["name"] = lut["name"].shift(1)
+
+        lut.loc[0, "name"] = "Background"
+
+    else:
+        first_row = {
+            "name": "Background",
+            "index": background_label,
+            "color": "FFFFFF",
+        }
+        first_row = {
+            col: first_row[col] if col in lut else np.nan
+            for col in lut.columns
+        }
+        lut = pd.concat([pd.DataFrame([first_row]), lut], ignore_index=True)
+
+    return (
+        sanitize_look_up_table(lut, atlas=labels_img)
+        .sort_values("index")
+        .reset_index(drop=True)
+    )
