@@ -2,20 +2,13 @@
 
 import warnings
 from copy import deepcopy
-from pathlib import Path
 from typing import Union
 
 import numpy as np
-import pandas as pd
 from scipy import ndimage
 from sklearn.utils.estimator_checks import check_is_fitted
 
 from nilearn import DEFAULT_SEQUENTIAL_CMAP, signal
-from nilearn._utils.bids import (
-    generate_atlas_look_up_table,
-    sanitize_look_up_table,
-)
-from nilearn._utils.cache_mixin import cache
 from nilearn._utils.class_inspect import get_params
 from nilearn._utils.docs import fill_doc
 from nilearn._utils.helpers import (
@@ -31,7 +24,11 @@ from nilearn._utils.param_validation import (
     check_reduction_strategy,
 )
 from nilearn.image import mean_img
-from nilearn.maskers.base_masker import _BaseSurfaceMasker
+from nilearn.maskers.base_masker import (
+    _BaseSurfaceMasker,
+    generate_lut,
+    mask_logger,
+)
 from nilearn.surface.surface import (
     SurfaceImage,
     at_least_2d,
@@ -79,6 +76,10 @@ class SurfaceLabelsMasker(_BaseSurfaceMasker):
         Labels corresponding to the labels image.
         This is used to improve reporting quality if provided.
 
+        "Background" can be included in this list of labels
+        to denote which values in the image should be considered
+        background value.
+
         .. warning::
             If the labels are not be consistent with the label values
             provided through ``labels_img``,
@@ -126,6 +127,8 @@ class SurfaceLabelsMasker(_BaseSurfaceMasker):
 
     %(verbose0)s
 
+    %(strategy)s
+
     reports : :obj:`bool`, default=True
         If set to True, data is saved in order to produce a report.
 
@@ -137,11 +140,17 @@ class SurfaceLabelsMasker(_BaseSurfaceMasker):
 
     Attributes
     ----------
+    %(clean_args_)s
+
     labels_img_ : :obj:`nibabel.nifti1.Nifti1Image`
         The labels image after fitting.
         If a mask_img was used,
         then masked vertices will have the background value.
 
+    lut_ : :obj:`pandas.DataFrame`
+        Look-up table derived from the ``labels`` or ``lut``
+        or from the values of the label image.
+
     mask_img_ : A 1D binary :obj:`~nilearn.surface.SurfaceImage` or None.
         The mask of the data.
         If no ``mask_img`` was passed at masker construction,
@@ -150,9 +159,8 @@ class SurfaceLabelsMasker(_BaseSurfaceMasker):
         where each vertex is ``True`` if all values across samples
         (for example across timepoints) is finite value different from 0.
 
-    lut_ : :obj:`pandas.DataFrame`
-        Look-up table derived from the ``labels`` or ``lut``
-        or from the values of the label image.
+    memory_ : joblib memory cache
+
     """
 
     def __init__(
@@ -213,15 +221,18 @@ class SurfaceLabelsMasker(_BaseSurfaceMasker):
 
     @property
     def labels_(self) -> list[Union[int, float]]:
-        """Return list of labels of the regions."""
+        """Return list of labels of the regions.
+
+        The background label is included if present in the image.
+        """
         check_is_fitted(self)
         lut = self.lut_
         return lut["index"].to_list()
 
     @property
     def region_names_(self) -> dict[int, str]:
-        """Return a dictionary containing the region names corresponding \n
-            to each column in the array returned by `transform`.
+        """Return a dictionary containing the region names corresponding \
+           to each column in the array returned by `transform`.
 
         The region names correspond to the labels provided
         in labels in input.
@@ -231,13 +242,18 @@ class SurfaceLabelsMasker(_BaseSurfaceMasker):
         .. versionadded:: 0.12.0
         """
         check_is_fitted(self)
-        lut = self.lut_
-        return lut.loc[lut["index"] != self.background_label, "name"].to_dict()
+
+        index = self.labels_
+        valid_ids = [id for id in index if id != self.background_label]
+
+        sub_df = self.lut_[self.lut_["index"].isin(valid_ids)]
+
+        return sub_df["name"].reset_index(drop=True).to_dict()
 
     @property
-    def region_ids_(self) -> dict[Union[str, int], int]:
-        """Return dictionary containing the region ids corresponding \n
-           to each column in the array \n
+    def region_ids_(self) -> dict[Union[str, int], Union[int, float]]:
+        """Return dictionary containing the region ids corresponding \
+           to each column in the array \
            returned by `transform`.
 
         The region id corresponding to ``region_signal[:,i]``
@@ -247,9 +263,19 @@ class SurfaceLabelsMasker(_BaseSurfaceMasker):
         .. versionadded:: 0.12.0
         """
         check_is_fitted(self)
-        lut = self.lut_
-        return lut["index"].to_dict()
 
+        index = self.labels_
+
+        region_ids_: dict[Union[str, int], Union[int, float]] = {}
+        if self.background_label in index:
+            index.pop(index.index(self.background_label))
+            region_ids_["background"] = self.background_label
+        for i, id in enumerate(index):
+            region_ids_[i] = id  # noqa : PERF403
+
+        return region_ids_
+
+    # TODO (nilearn >= 0.13.0)
     @fill_doc
     @rename_parameters(
         replacement_params={"img": "imgs"}, end_version="0.13.0"
@@ -290,6 +316,10 @@ class SurfaceLabelsMasker(_BaseSurfaceMasker):
                 "but not both."
             )
 
+        self._fit_cache()
+
+        mask_logger("load_regions", self.labels_img, verbose=self.verbose)
+
         self.labels_img_ = deepcopy(self.labels_img)
 
         self.mask_img_ = self._load_mask(imgs)
@@ -322,28 +352,9 @@ class SurfaceLabelsMasker(_BaseSurfaceMasker):
                     stacklevel=find_stack_level(),
                 )
 
-        self._shelving = False
-
-        # generate a look up table if one was not provided
-        if self.lut is not None:
-            if isinstance(self.lut, (str, Path)):
-                lut = pd.read_table(self.lut, sep=None)
-            else:
-                lut = self.lut
-        elif self.labels:
-            lut = generate_atlas_look_up_table(
-                function=None,
-                name=self.labels,
-                index=self.labels_img_,
-            )
-        else:
-            lut = generate_atlas_look_up_table(
-                function=None, index=self.labels_img_
-            )
-
-        self.lut_ = sanitize_look_up_table(lut, atlas=self.labels_img_)
-
-        self._shelving = False
+        self.lut_ = generate_lut(
+            self.labels_img_, self.background_label, self.lut, self.labels
+        )
 
         if self.clean_args is None:
             self.clean_args_ = {}
@@ -375,6 +386,8 @@ class SurfaceLabelsMasker(_BaseSurfaceMasker):
 
         self._reporting_data = self._generate_reporting_data()
 
+        mask_logger("fit_done", verbose=self.verbose)
+
         return self
 
     def _generate_reporting_data(self):
@@ -455,29 +468,21 @@ class SurfaceLabelsMasker(_BaseSurfaceMasker):
 
         reduction_function = getattr(ndimage, self.strategy)
 
+        mask_logger("extracting", verbose=self.verbose)
+
         for n, sample in enumerate(np.rollaxis(img_data, -1)):
             tmp = np.asarray(
                 reduction_function(sample, labels=labels_data, index=index)
             )
             region_signals[n] = tmp
 
-        parameters = get_params(
-            self.__class__,
-            self,
-            ignore=[
-                "mask_img",
-            ],
-        )
+        mask_logger("cleaning", verbose=self.verbose)
+
+        parameters = get_params(self.__class__, self, ignore=["mask_img"])
         parameters["clean_args"] = self.clean_args_
 
         # signal cleaning here
-        region_signals = cache(
-            signal.clean,
-            memory=self.memory,
-            func_memory_level=2,
-            memory_level=self.memory_level,
-            shelve=self._shelving,
-        )(
+        region_signals = self._cache(signal.clean, func_memory_level=2)(
             region_signals,
             detrend=parameters["detrend"],
             standardize=parameters["standardize"],
@@ -510,6 +515,8 @@ class SurfaceLabelsMasker(_BaseSurfaceMasker):
 
         signals = self._check_array(signals)
 
+        mask_logger("inverse_transform", verbose=self.verbose)
+
         imgs = signals_to_surf_img_labels(
             signals,
             np.asarray(self.labels_),
