@@ -68,26 +68,75 @@ def test_check_estimator_nilearn(estimator, check, name):  # noqa: ARG001
 
 
 def test_surface_label_masker_fit(surf_label_img):
-    """Test fit and check estimated attributes.
-
-    0 value in data is considered as background
-    and should not be listed in the labels.
-    """
+    """Test fit and check estimated attributes."""
     masker = SurfaceLabelsMasker(labels_img=surf_label_img)
     masker = masker.fit()
 
     assert masker.n_elements_ == 1
     assert masker.labels_ == [0, 1]
     assert masker._reporting_data is not None
-    assert masker.lut_["name"].to_list() == ["0", "1"]
-    assert masker.region_names_ == {1: "1"}
-    assert masker.region_ids_ == {0: 0, 1: 1}
+    assert masker.lut_["name"].to_list() == ["Background", "1"]
+    assert masker.region_names_ == {0: "1"}
+    assert masker.region_ids_ == {"background": 0, 0: 1}
 
 
-def test_surface_label_masker_fit_with_names(surf_label_img):
-    """Check passing labels is reflected in attributes."""
+def test_surface_label_masker_fit_transform(surf_label_img, surf_img_1d):
+    """Test transform does not return any value for the background.
+
+    A single scalar should be return as the mask only has 1 region.
+    """
+    masker = SurfaceLabelsMasker(labels_img=surf_label_img)
+    signal = masker.fit_transform(surf_img_1d)
+
+    assert masker.n_elements_ == 1
+    assert signal.size == masker.n_elements_
+
+
+@pytest.mark.parametrize("labels", [["Background", "bar"], ["bar"]])
+def test_surface_label_masker_fit_with_labels(surf_label_img, labels):
+    """Check passing labels is reflected in attributes.
+
+    Should behave the same even if "Background" is not in the list of labels
+    """
+    masker = SurfaceLabelsMasker(labels_img=surf_label_img, labels=labels)
+
+    masker = masker.fit()
+
+    assert masker.n_elements_ == 1
+    assert masker.labels_ == [0, 1]
+    assert masker.lut_["name"].to_list() == ["Background", "bar"]
+    assert masker.region_names_ == {0: "bar"}
+    assert masker.region_ids_ == {"background": 0, 0: 1}
+
+
+@pytest.mark.parametrize("labels", [["bar"], ["bar", "Background"]])
+def test_surface_label_masker_fit_background_label(surf_label_img, labels):
+    """Check that labels and background label can be matched properly.
+
+    Here we say that the background label is 1 and not 0.
+
+    Should behave the same even if "Background" is not in the list of labels
+    """
     masker = SurfaceLabelsMasker(
-        labels_img=surf_label_img, labels=["background", "bar", "foo"]
+        labels_img=surf_label_img, labels=labels, background_label=1
+    )
+
+    masker = masker.fit()
+
+    assert masker.n_elements_ == 1
+    assert masker.labels_ == [0, 1]
+    assert masker.lut_["name"].to_list() == ["bar", "Background"]
+    assert masker.region_names_ == {0: "bar"}
+    assert masker.region_ids_ == {"background": 1, 0: 0}
+
+
+def test_surface_label_masker_fit_too_many_labels(surf_label_img):
+    """Check passing labels is reflected in attributes.
+
+    Check warning are thrown when too many are passed.
+    """
+    masker = SurfaceLabelsMasker(
+        labels_img=surf_label_img, labels=["Background", "bar", "foo"]
     )
 
     with pytest.warns(UserWarning, match="Dropping excess names values."):
@@ -95,10 +144,18 @@ def test_surface_label_masker_fit_with_names(surf_label_img):
 
     assert masker.n_elements_ == 1
     assert masker.labels_ == [0, 1]
-    assert masker.lut_["name"].to_list() == ["background", "bar"]
+    assert masker.lut_["name"].to_list() == ["Background", "bar"]
+    assert masker.region_names_ == {0: "bar"}
+    assert masker.region_ids_ == {"background": 0, 0: 1}
 
+
+def test_surface_label_masker_fit_too_few_labels(surf_label_img):
+    """Check passing labels is reflected in attributes.
+
+    Check warning are thrown when too few are passed.
+    """
     masker = SurfaceLabelsMasker(
-        labels_img=surf_label_img, labels=["background"]
+        labels_img=surf_label_img, labels=["Background"]
     )
 
     with pytest.warns(UserWarning, match="Padding 'names' with 'unknown'"):
@@ -106,7 +163,9 @@ def test_surface_label_masker_fit_with_names(surf_label_img):
 
     assert masker.n_elements_ == 1
     assert masker.labels_ == [0, 1]
-    assert masker.lut_["name"].to_list() == ["background", "unknown"]
+    assert masker.lut_["name"].to_list() == ["Background", "unknown"]
+    assert masker.region_names_ == {0: "unknown"}
+    assert masker.region_ids_ == {"background": 0, 0: 1}
 
 
 def test_surface_label_masker_fit_with_lut(surf_label_img, tmp_path):
@@ -117,7 +176,7 @@ def test_surface_label_masker_fit_with_lut(surf_label_img, tmp_path):
     - a csv file (doc strings only mention TSV but testing for robustness)
     - a dataframe
     """
-    lut_df = pd.DataFrame({"index": [0, 1], "name": ["background", "bar"]})
+    lut_df = pd.DataFrame({"index": [0, 1], "name": ["Background", "bar"]})
 
     lut_tsv = tmp_path / "lut.tsv"
     lut_df.to_csv(lut_tsv, sep="\t", index=False)
@@ -128,9 +187,77 @@ def test_surface_label_masker_fit_with_lut(surf_label_img, tmp_path):
     for lut in [lut_tsv, lut_csv, lut_df, str(lut_tsv)]:
         masker = SurfaceLabelsMasker(labels_img=surf_label_img, lut=lut).fit()
 
+        if isinstance(lut, pd.DataFrame):
+            assert list(masker.lut.columns) == list(masker.lut_.columns)
         assert masker.n_elements_ == 1
         assert masker.labels_ == [0, 1]
-        assert masker.lut_["name"].to_list() == ["background", "bar"]
+        assert masker.lut_["name"].to_list() == ["Background", "bar"]
+
+
+@pytest.mark.parametrize(
+    "background_label, n_expected_regions", [(0, 3), (1, 2)]
+)
+@pytest.mark.parametrize(
+    "kwargs",
+    [
+        {},
+        {
+            "lut": pd.DataFrame(
+                {
+                    "index": [0, 1, 2, 3],
+                    "name": ["Background", "Foo", "Bar", "Baz"],
+                }
+            )
+        },
+        {
+            "lut": pd.DataFrame(
+                {
+                    "index": [0, 1, 2, 3],
+                    "name": ["Unknown", "Foo", "Bar", "Baz"],
+                }
+            )
+        },
+        {"labels": ["background", "Foo", "Bar", "Baz"]},
+    ],
+)
+def test_label_image_no_background_missing_regions(
+    surf_mesh, surf_img_2d, background_label, n_expected_regions, kwargs
+):
+    """Test label image with no background.
+
+    Compare behavior when background is present in label image
+    (background_label=1) or not (background_label=0).
+
+    Regression test for https://github.com/nilearn/nilearn/issues/5596
+    """
+    data = {
+        "left": np.asarray([3, 3, 1, 1]),
+        "right": np.asarray([1, 1, 3, 2, 3]),
+    }
+    label_img = SurfaceImage(surf_mesh, data)
+
+    labels_masker = SurfaceLabelsMasker(
+        labels_img=label_img, background_label=background_label, **kwargs
+    ).fit()
+
+    if "lut" in kwargs:
+        # when reset_index() does not use drop=True,
+        # extra columns were added
+        assert list(kwargs["lut"].columns) == list(labels_masker.lut_.columns)
+
+    masked_data = labels_masker.transform(surf_img_2d(2))
+
+    assert masked_data.shape[1] == n_expected_regions
+    assert len(labels_masker.region_names_) == n_expected_regions
+
+    if background_label == 1:
+        assert "Background" in labels_masker.lut_["name"].to_list()
+        assert len(labels_masker.labels_) == n_expected_regions + 1
+        assert len(labels_masker.region_ids_) == n_expected_regions + 1
+    else:
+        assert "Background" not in labels_masker.lut_["name"].to_list()
+        assert len(labels_masker.labels_) == n_expected_regions
+        assert len(labels_masker.region_ids_) == n_expected_regions
 
 
 def test_surface_label_masker_error_names_and_lut(surf_label_img):
@@ -176,7 +303,7 @@ def test_surface_label_masker_transform(surf_label_img, surf_img_1d, strategy):
     signal = masker.transform(surf_img_1d)
 
     assert isinstance(signal, np.ndarray)
-    assert signal.shape == ()
+    assert signal.size == 1
 
 
 def test_surface_label_masker_transform_with_mask(surf_mesh, surf_img_2d):
@@ -214,6 +341,15 @@ def test_surface_label_masker_transform_with_mask(surf_mesh, surf_img_2d):
     assert masker.n_elements_ == expected_n_regions
     assert signal.shape == (n_timepoints, masker.n_elements_)
 
+    # note that even if the label image contained no vertex with
+    # background level values, some vertices were masked
+    # and given background value
+    # so background should appear here.
+    assert masker.labels_ == [0, 1, 2]
+    assert masker.lut_["name"].to_list() == ["Background", "1", "2"]
+    assert masker.region_names_ == {0: "1", 1: "2"}
+    assert masker.region_ids_ == {"background": 0, 0: 1, 1: 2}
+
 
 @pytest.fixture
 def polydata_labels():
@@ -332,6 +468,17 @@ def test_surface_label_masker_check_output_1d(
 
     assert_array_equal(signal, np.asarray(expected_signal))
 
+    assert masker.labels_ == [0, 1, 2, 10, 20]
+    assert masker.lut_["name"].to_list() == [
+        "Background",
+        "1",
+        "2",
+        "10",
+        "20",
+    ]
+    assert masker.region_names_ == {0: "1", 1: "2", 2: "10", 3: "20"}
+    assert masker.region_ids_ == {"background": 0, 0: 1, 1: 2, 2: 10, 3: 20}
+
     # also check the output of inverse_transform
     img = masker.inverse_transform(signal)
     assert img.shape[0] == surf_img_1d.shape[0]
@@ -346,6 +493,58 @@ def test_surface_label_masker_check_output_1d(
     assert_array_equal(img.data.parts["right"], expected_inverse_data["right"])
 
 
+def test_surface_label_masker_lut_unsorted(
+    surf_mesh,
+    polydata_labels,
+    expected_signal,
+    data_left_1d_with_expected_mean,
+    data_right_1d_with_expected_mean,
+):
+    """Test lut with wrong order of regions.
+
+    LUT, region_ids, region_names should be properly sorted after fit.
+    Result of region_ids, region_names
+    should still match content of extracted signals.
+    """
+    surf_label_img = SurfaceImage(surf_mesh, polydata_labels)
+
+    lut = pd.DataFrame(
+        columns=["index", "name"],
+        data=[[1.0, "one"], [20.0, "twenty"], [10.0, "ten"], [2.0, "two"]],
+    )
+
+    masker = SurfaceLabelsMasker(labels_img=surf_label_img, lut=lut)
+    masker = masker.fit()
+
+    assert list(masker.lut.columns) == list(masker.lut_.columns)
+    assert masker.labels_ == [0.0, 1.0, 2.0, 10.0, 20.0]
+    assert masker.lut_["name"].to_list() == [
+        "Background",
+        "one",
+        "two",
+        "ten",
+        "twenty",
+    ]
+    assert masker.region_names_ == {0: "one", 1: "two", 2: "ten", 3: "twenty"}
+    assert masker.region_ids_ == {
+        "background": 0,
+        0: 1.0,
+        1: 2.0,
+        2: 10.0,
+        3: 20.0,
+    }
+
+    data = {
+        "left": data_left_1d_with_expected_mean,
+        "right": data_right_1d_with_expected_mean,
+    }
+    surf_img_1d = SurfaceImage(surf_mesh, data)
+    signal = masker.transform(surf_img_1d)
+
+    assert isinstance(signal, np.ndarray)
+    assert_array_equal(signal, np.asarray(expected_signal))
+
+
 def test_surface_label_masker_check_output_2d(
     surf_mesh,
     polydata_labels,
@@ -391,6 +590,17 @@ def test_surface_label_masker_check_output_2d(
     expected_signal = np.asarray([expected_signal - 1, expected_signal + 1])
     assert_array_equal(signal, expected_signal)
 
+    assert masker.labels_ == [0, 1, 2, 10, 20]
+    assert masker.lut_["name"].to_list() == [
+        "Background",
+        "1",
+        "2",
+        "10",
+        "20",
+    ]
+    assert masker.region_names_ == {0: "1", 1: "2", 2: "10", 3: "20"}
+    assert masker.region_ids_ == {"background": 0, 0: 1, 1: 2, 2: 10, 3: 20}
+
     # also check the output of inverse_transform
     img = masker.inverse_transform(signal)
 
