@@ -7,17 +7,14 @@ import numpy as np
 from joblib import Parallel, delayed
 from scipy.ndimage import binary_dilation, binary_erosion
 
-from nilearn._utils import (
-    as_ndarray,
-    check_niimg,
-    check_niimg_3d,
-    fill_doc,
-    logger,
-)
+from nilearn._utils import logger
 from nilearn._utils.cache_mixin import cache
+from nilearn._utils.docs import fill_doc
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.ndimage import get_border_data, largest_connected_component
 from nilearn._utils.niimg import safe_get_data
+from nilearn._utils.niimg_conversions import check_niimg, check_niimg_3d
+from nilearn._utils.numpy_conversions import as_ndarray
 from nilearn._utils.param_validation import check_params
 from nilearn.datasets import (
     load_mni152_gm_template,
@@ -707,7 +704,7 @@ def compute_brain_mask(
         template,
         target_img,
         copy_header=True,
-        force_resample=False,  # TODO set to True in 0.13.0
+        force_resample=False,  # TODO (nilearn >= 0.13.0) update to True
     )
 
     mask = (get_data(resampled_template) >= threshold).astype("int8")
@@ -736,7 +733,6 @@ def compute_multi_brain_mask(
     memory=None,
     verbose=0,
     mask_type="whole-brain",
-    **kwargs,
 ):
     """Compute the whole-brain, grey-matter or white-matter mask \
     for a list of images.
@@ -773,14 +769,6 @@ def compute_multi_brain_mask(
 
     %(verbose0)s
 
-    .. note::
-        Argument not used but kept to fit the API
-
-    **kwargs : optional arguments
-        Arguments such as 'target_affine' are used in the call of other
-        masking strategies, which then would raise an error for this function
-        which does not need such arguments.
-
     Returns
     -------
     mask : :class:`nibabel.nifti1.Nifti1Image`
