@@ -10,10 +10,10 @@ from matplotlib.colorbar import ColorbarBase
 from matplotlib.colors import LinearSegmentedColormap, ListedColormap
 from matplotlib.transforms import Bbox
 
-from nilearn._utils import check_niimg_3d, fill_doc
+from nilearn._utils.docs import fill_doc
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.niimg import is_binary_niimg, safe_get_data
-from nilearn._utils.niimg_conversions import _check_fov
+from nilearn._utils.niimg_conversions import _check_fov, check_niimg_3d
 from nilearn._utils.param_validation import check_params
 from nilearn.image import get_data, new_img_like, reorder_img
 from nilearn.image.resampling import get_bounds, get_mask_bounds, resample_img
@@ -418,6 +418,14 @@ class BaseSlicer:
                     # should be given as (lower, upper).
                     levels.append(np.inf)
 
+            if "linewidths" in kwargs:
+                warnings.warn(
+                    "'linewidths' is not supported for filled contours",
+                    UserWarning,
+                    stacklevel=find_stack_level(),
+                )
+                kwargs.pop("linewidths")
+
             self._map_show(img, type="contourf", threshold=threshold, **kwargs)
 
         plt.draw_if_interactive()
@@ -488,6 +496,7 @@ class BaseSlicer:
             xmin_, xmax_, ymin_, ymax_, zmin_, zmax_ = get_mask_bounds(
                 new_img_like(img, not_mask, affine)
             )
+
         elif hasattr(data, "mask") and isinstance(data.mask, np.ndarray):
             not_mask = np.logical_not(data.mask)
             xmin_, xmax_, ymin_, ymax_, zmin_, zmax_ = get_mask_bounds(
@@ -1762,7 +1771,6 @@ class BaseStackedSlicer(BaseSlicer):
             Extra keyword arguments are passed to function
             :func:`matplotlib.pyplot.axhline`.
         """
-        pass
 
 
 class XSlicer(BaseStackedSlicer):
@@ -2263,7 +2271,6 @@ class MosaicSlicer(BaseSlicer):
             Extra keyword arguments are passed to function
             :func:`matplotlib.pyplot.axhline`.
         """
-        pass
 
 
 SLICERS = {
