@@ -7,12 +7,9 @@ import pandas as pd
 from mpl_toolkits.axes_grid1 import make_axes_locatable
 
 from nilearn import DEFAULT_DIVERGING_CMAP
-from nilearn._utils import (
-    constrained_layout_kwargs,
-    fill_doc,
-    rename_parameters,
-)
+from nilearn._utils.docs import fill_doc
 from nilearn._utils.glm import check_and_load_tables
+from nilearn._utils.helpers import constrained_layout_kwargs, rename_parameters
 from nilearn.glm.first_level import check_design_matrix
 from nilearn.glm.first_level.experimental_paradigm import check_events
 from nilearn.plotting._utils import save_figure_if_needed
@@ -268,6 +265,7 @@ def plot_matrix(
     return display
 
 
+# TODO (nilearn >= 0.13.0)
 @fill_doc
 @rename_parameters({"ax": "axes"}, end_version="0.13.0")
 def plot_contrast_matrix(
@@ -339,6 +337,7 @@ def plot_contrast_matrix(
     return save_figure_if_needed(axes, output_file)
 
 
+# TODO (nilearn >= 0.13.0)
 @fill_doc
 @rename_parameters({"ax": "axes"}, end_version="0.13.0")
 def plot_design_matrix(
