@@ -6,15 +6,15 @@ import numpy as np
 import pandas as pd
 
 from nilearn import DEFAULT_DIVERGING_CMAP
-from nilearn._utils import fill_doc
+from nilearn._utils.docs import fill_doc
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.niimg_conversions import check_niimg_3d
 from nilearn._utils.param_validation import check_params
 from nilearn.image import get_data
+from nilearn.plotting._engine_utils import create_colormap_from_lut
 from nilearn.plotting._utils import (
     DEFAULT_ENGINE,
     check_threshold_not_negative,
-    create_colormap_from_lut,
 )
 from nilearn.plotting.surface._utils import (
     DEFAULT_HEMI,
@@ -386,6 +386,11 @@ def plot_surf_contours(
     )
     check_extensions(roi_map, DATA_EXTENSIONS, FREESURFER_DATA_EXTENSIONS)
 
+    if "darkness" not in kwargs:
+        # TODO (nilearn >= 0.13.0) remove when darkness is removed
+        # added now to prevent some extra warnings
+        kwargs["darkness"] = None
+
     backend = get_surface_backend(DEFAULT_ENGINE)
     fig = backend._plot_surf_contours(
         surf_mesh=surf_mesh,
@@ -503,7 +508,7 @@ def plot_surf_stat_map(
         When using matplotlib as engine,
         `avg_method` will default to ``"mean"`` if ``None`` is passed.
 
-        .. versionadded:: 0.10.3dev
+        .. versionadded:: 0.10.3
 
     %(threshold)s
         Default=None
@@ -996,7 +1001,7 @@ def plot_surf_roi(
             f"{roi.ndim} dimensions"
         )
     if (roi < 0).any():
-        # TODO raise ValueError in release 0.13
+        # TODO (nilearn >= 0.13.0) raise ValueError
         warn(
             (
                 "Negative values in roi_map will no longer be allowed in"
@@ -1023,7 +1028,7 @@ def plot_surf_roi(
         vmax = float(1 + np.nanmax(roi))
 
     if not np.array_equal(roi[idx_not_na], roi[idx_not_na].astype(int)):
-        # TODO raise ValueError in release 0.13
+        # TODO (nilearn >= 0.13.0) raise ValueError
         warn(
             (
                 "Non-integer values in roi_map will no longer be allowed "
