@@ -15,8 +15,9 @@ from scipy import signal as sp_signal
 from scipy.interpolate import CubicSpline
 from sklearn.utils import as_float_array, gen_even_slices
 
-from nilearn._utils import fill_doc, stringify_path
+from nilearn._utils.docs import fill_doc
 from nilearn._utils.exceptions import AllVolumesRemovedError
+from nilearn._utils.helpers import stringify_path
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.numpy_conversions import as_ndarray, csv_to_array
 from nilearn._utils.param_validation import (
@@ -94,6 +95,7 @@ def standardize_signal(
             signals /= std
 
         elif (standardize == "zscore") or (standardize is True):
+            # TODO (nilearn >= 0.13.0) deprecate nearest interpolation
             std_strategy_default = (
                 "The default strategy for standardize is currently 'zscore' "
                 "which incorrectly uses population std to calculate sample "
@@ -894,6 +896,7 @@ def _censor_signals(signals, confounds, sample_mask):
 def _interpolate_volumes(volumes, sample_mask, t_r, extrapolate):
     """Interpolate censored volumes in signals/confounds."""
     if extrapolate:
+        # TODO (nilearn 0.13.0)
         extrapolate_default = (
             "By default the cubic spline interpolator extrapolates "
             "the out-of-bounds censored volumes in the data run. This "
